#!/bin/csh -f

# shell program to use nsp2regex.pl on art.cnt and authority.cnt to
# produce art.regex and authority.regex, respectively.

# subtest 1
echo "Running nsp2regex.pl on art.cnt using token.txt"

set TESTFILE     = "art.cnt"
set TOKENFILE    = "token.txt"
set TARGETFILE = "art.regex.reqd"   

# first check if these files exist. if any one does not, quit
if (!(-e $TESTFILE)) then
    echo "File $TESTFILE does not exist... aborting"
    exit
endif

if (!(-e $TOKENFILE)) then
    echo "File $TOKENFILE does not exist... aborting"
    exit
endif

if (!(-e $TARGETFILE)) then
    echo "File $TARGETFILE does not exist... aborting"
    exit
endif

# test on art.cnt
echo "Testing nsp2regex.pl thusly: nsp2regex.pl $TESTFILE --token $TOKENFILE > art.regex"
nsp2regex.pl $TESTFILE --token $TOKENFILE > art.regex

# find diffs
diff art.regex $TARGETFILE > difference
if (-z difference) then
    echo "   Output matches target output (as provided in $TARGETFILE)"
else
    echo "Following differences exist between art.regex and $TARGETFILE :"
    cat difference
endif
/bin/rm -f difference
/bin/rm -f art.regex

# subtest 2
echo "Running nsp2regex.pl on authority.cnt using token.txt"

set TESTFILE     = "authority.cnt"
set TOKENFILE    = "token.txt"
set TARGETFILE   = "authority.regex.reqd"   

# first check if these files exist. if any one does not, quit
if (!(-e $TESTFILE)) then
    echo "File $TESTFILE does not exist... aborting"
    exit
endif

if (!(-e $TOKENFILE)) then
    echo "File $TOKENFILE does not exist... aborting"
    exit
endif

if (!(-e $TARGETFILE)) then
    echo "File $TARGETFILE does not exist... aborting"
    exit
endif

# test on art.cnt
echo "Testing nsp2regex.pl thusly: nsp2regex.pl $TESTFILE --token $TOKENFILE > authority.regex"
nsp2regex.pl $TESTFILE --token $TOKENFILE > authority.regex

# find diffs
diff authority.regex $TARGETFILE > difference
if (-z difference) then
    echo "   Output matches target output (as provided in $TARGETFILE)"
else
    echo "Following differences exist between authority.regex and $TARGETFILE :"
    cat difference
endif
/bin/rm -f difference

/bin/rm -f authority.regex

