#!/bin/csh -f

# shell program to use xml2arff.pl on the art and authority files to
# produce corresponding arff files.

# subtest 1
echo "Running xml2arff.pl on the art files"

set TRAINFILE       = "art.train.xml.tilde.reqd"
set TESTFILE        = "art.test.xml.reqd"
set REGEXFILE       = "art.regex.reqd"
set TARGETTRAINFILE = "art.train.arff.reqd"
set TARGETTESTFILE  = "art.test.arff.reqd"

# first check if these files exist. if any one does not, quit
if (!(-e $TRAINFILE)) then
    echo "File $TESTFILE does not exist... aborting"
    exit
endif

if (!(-e $TESTFILE)) then
    echo "File $TESTFILE does not exist... aborting"
    exit
endif

if (!(-e $REGEXFILE)) then
    echo "File $REGEXFILE does not exist... aborting"
    exit
endif

if (!(-e $TARGETTRAINFILE)) then
    echo "File $TARGETTRAINFILE does not exist... aborting"
    exit
endif

if (!(-e $TARGETTESTFILE)) then
    echo "File $TARGETTESTFILE does not exist... aborting"
    exit
endif

# test on art files
echo "Testing xml2arff.pl thusly:"
echo "xml2arff.pl $REGEXFILE --training $TRAINFILE --test $TESTFILE"
xml2arff.pl $REGEXFILE --training $TRAINFILE --test $TESTFILE

# find diffs for training file
diff $TRAINFILE.arff $TARGETTRAINFILE > difference
if (-z difference) then
    echo "   Output matches target output (as provided in $TARGETTRAINFILE)"
else
    echo "Following differences exist between $TRAINFILE.arff and $TARGETTRAINFILE :"
    cat difference
endif
/bin/rm -f difference
/bin/rm -f $TRAINFILE.arff

# find diffs for test file
diff $TESTFILE.arff $TARGETTESTFILE > difference
if (-z difference) then
    echo "   Output matches target output (as provided in $TARGETTESTFILE)"
else
    echo "Following differences exist between $TESTFILE.arff and $TARGETTESTFILE :"
    cat difference
endif
/bin/rm -f difference
/bin/rm -f $TESTFILE.arff

# subtest 2
echo "Running xml2arff.pl on the authority files"

set TRAINFILE       = "authority.train.xml.tilde.reqd"
set TESTFILE        = "authority.test.xml.reqd"
set REGEXFILE       = "authority.regex.reqd"
set TARGETTRAINFILE = "authority.train.arff.reqd"
set TARGETTESTFILE  = "authority.test.arff.reqd"

# first check if these files exist. if any one does not, quit
if (!(-e $TRAINFILE)) then
    echo "File $TESTFILE does not exist... aborting"
    exit
endif

if (!(-e $TESTFILE)) then
    echo "File $TESTFILE does not exist... aborting"
    exit
endif

if (!(-e $REGEXFILE)) then
    echo "File $REGEXFILE does not exist... aborting"
    exit
endif

if (!(-e $TARGETTRAINFILE)) then
    echo "File $TARGETTRAINFILE does not exist... aborting"
    exit
endif

if (!(-e $TARGETTESTFILE)) then
    echo "File $TARGETTESTFILE does not exist... aborting"
    exit
endif

# test on authority files
echo "Testing xml2arff.pl thusly:"
echo "xml2arff.pl $REGEXFILE --training $TRAINFILE --test $TESTFILE"
xml2arff.pl $REGEXFILE --training $TRAINFILE --test $TESTFILE

# find diffs for training file
diff $TRAINFILE.arff $TARGETTRAINFILE > difference
if (-z difference) then
    echo "   Output matches target output (as provided in $TARGETTRAINFILE)"
else
    echo "Following differences exist between $TRAINFILE.arff and $TARGETTRAINFILE :"
    cat difference
endif
/bin/rm -f difference
/bin/rm -f $TRAINFILE.arff

# find diffs for test file
diff $TESTFILE.arff $TARGETTESTFILE > difference
if (-z difference) then
    echo "   Output matches target output (as provided in $TARGETTESTFILE)"
else
    echo "Following differences exist between $TESTFILE.arff and $TARGETTESTFILE :"
    cat difference
endif
/bin/rm -f difference
/bin/rm -f $TESTFILE.arff

