#!/bin/csh -f

# shell program to use WekaClassify on the art and authority test
# files to generate answers for test instances.

# subtest 1
echo "Running WekaClassify on the art files"

set TESTFILE        = "art.test.arff.reqd"
set MODELFILE       = "art.model"
set TARGETFILE      = "art.answers.reqd"

# first check if these files exist. if any one does not, quit
if (!(-e $TESTFILE)) then
    echo "File $TESTFILE does not exist... aborting"
    exit
endif

if (!(-e $MODELFILE)) then
    echo "File $MODELFILE does not exist... aborting"
    exit
endif

if (!(-e $TARGETFILE)) then
    echo "File $TARGETFILE does not exist... aborting"
    exit
endif

# create the model file
java weka.classifiers.trees.J48 -d $MODELFILE -t $TESTFILE -x 2

# test on art files
echo "Testing WekaClassify thusly:"
echo "java WekaClassify -l art.model -T art.test.arff.reqd > art.answers"
java WekaClassify -l art.model -T art.test.arff.reqd > art.answers

# find diffs for training file
diff art.answers $TARGETFILE > difference
if (-z difference) then
    echo "   Output matches target output (as provided in $TARGETFILE)"
else
    echo "Following differences exist between art.answers and $TARGETFILE :"
    cat difference
endif
/bin/rm -f difference
/bin/rm -f art.answers


# subtest 2
echo "Running WekaClassify on the authority files"

set TESTFILE        = "authority.test.arff.reqd"
set MODELFILE       = "authority.model"
set TARGETFILE      = "authority.answers.reqd"

# create the model file
java weka.classifiers.trees.J48 -d $MODELFILE -t $TESTFILE -x 2

# first check if these files exist. if any one does not, quit
if (!(-e $TESTFILE)) then
    echo "File $TESTFILE does not exist... aborting"
    exit
endif

if (!(-e $MODELFILE)) then
    echo "File $MODELFILE does not exist... aborting"
    exit
endif

if (!(-e $TARGETFILE)) then
    echo "File $TARGETFILE does not exist... aborting"
    exit
endif

# test on authority files
echo "Testing WekaClassify thusly:"
echo "java WekaClassify -l authority.model -T authority.test.arff.reqd > authority.answers"
java WekaClassify -l authority.model -T authority.test.arff.reqd > authority.answers

# find diffs for training file
diff authority.answers $TARGETFILE > difference
if (-z difference) then
    echo "   Output matches target output (as provided in $TARGETFILE)"
else
    echo "Following differences exist between authority.answers and $TARGETFILE :"
    cat difference
endif
/bin/rm -f difference
/bin/rm -f authority.answers

