#!/usr/local/bin/perl -w

# the senseval 2 data uses wordnet sense tags, which include
# an embedded %. Unfortunately weka treats those as comments.
# So we convert the % to ~ for weka, and thereafter convert
# the ~ back to % for reporting senseval results

# Copyright (C) 2001
# Ted Pedersen, University of Minnesota, Duluth
# tpederse@d.umn.edu
# Satanjeev Banerjee, University of Minnesota, Duluth
# bane0025@d.umn.edu
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
#
#-----------------------------------------------------------------------------
#                              Start of program
#-----------------------------------------------------------------------------

# we have to use commandline options, so use the necessary package!
use Getopt::Long;

# first check if no commandline options have been provided... in which case
# print out the usage notes!
if ( $#ARGV == -1 )
{
    &minimalUsageNotes();
    exit;
}

# now get the options!
GetOptions("version", "help");

# if help has been requested, print out help!
if ( defined $opt_help )
{
    $opt_help = $opt_help;
    &showHelp();
    exit;
}

# if version has been requested, show version!
if ( defined $opt_version )
{
    $opt_version = $opt_version;
    &showVersion();
    exit;
}

while (<>)
{
    if (/%([0-9]+):([0-9]+):([0-9]+):/)
    {
	s/%([0-9]+):([0-9]+):([0-9]+):/~$1:$2:$3:/g;
    }
    elsif (/~([0-9]+):([0-9]+):([0-9]+):/)
    {
	s/~([0-9]+):([0-9]+):([0-9]+):/%$1:$2:$3:/g;
    }
    print $_;
}

# thats it!

# function to output a minimal usage note when the user has not provided any
# commandline options
sub minimalUsageNotes
{
    print "Usage: tilde.pl [OPTIONS] SOURCE\n";
    askHelp();
}

# function to output help messages for this program
sub showHelp
{
    print "Usage: tilde.pl [OPTIONS] SOURCE\n\n";

    print "Replaces the \"%\" sign in the mnemonic sense-id of the SOURCE\n";
    print "Senseval xml file with a \"~\" sign, or vice versa. This program\n";
    print "automatically detects which sign (\"%\" or \"~\") is being used, and\n";
    print "replaces it with the other sign.\n\n";

    print "OPTIONS:\n\n";

    print "  --version          Prints the version number.\n\n";

    print "  --help             Prints this help message.\n\n";

}

# function to output the version number
sub showVersion
{
    print "tilde.pl  -  Version 0.1\n";
    print "A component of SenseTools 0.1\n";
    print "Copyright (C) 2001, Ted Pedersen & Satanjeev Banerjee\n";
}

# function to output "ask for help" message when the user's goofed up!
sub askHelp 
{
    print "Type tilde.pl --help for help.\n";
}
